@@ -22,18 +22,60 @@ module Google
   module Apis
     module ServiceusageV1
       
+      class AddEnableRulesMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class AddEnableRulesResponse
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class AdminQuotaPolicy
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Analysis
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class AnalysisResult
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class AnalyzeConsumerPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class AnalyzeConsumerPolicyResponse
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Api
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Aspect
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class AuthProvider
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -100,6 +142,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class BatchingConfigProto
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class BatchingDescriptorProto
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class BatchingSettingsProto
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Billing
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -130,6 +190,30 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ConsumerPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class ContentSecurity
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class ContentSecurityPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class ContentSecurityProvider
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Context
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -226,6 +310,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class EnableRule
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class EnableServiceRequest
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -256,12 +346,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ExperimentalFeatures
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Field
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class FieldPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class GetServiceIdentityMetadata
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -316,6 +418,96 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class GoogleApiServiceusageV2alphaConsumerPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2alphaEnableRule
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2alphaUpdateConsumerPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaAnalysis
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaAnalysisResult
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaAnalyzeConsumerPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaConsumerPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaEnableRule
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaImpact
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaMcpEnableRule
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaMcpPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaMcpService
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaUpdateConsumerPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GoogleApiServiceusageV2betaUpdateMcpPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Http
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -328,6 +520,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Impact
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class ImportAdminOverridesMetadata
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -418,12 +616,36 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class McpEnableRule
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class McpPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class McpService
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class MethodProp
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class MethodPolicy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class MethodSettings
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -544,12 +766,30 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class RemoveEnableRulesMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class RemoveEnableRulesResponse
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class RubySettings
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class SelectiveGapicGeneration
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class ServiceIdentity
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -604,6 +844,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class UpdateConsumerPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class UpdateContentSecurityPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class UpdateMcpPolicyMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Usage
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -616,6 +874,20 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class AddEnableRulesMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class AddEnableRulesResponse
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :added_values, as: 'addedValues'
+          property :parent, as: 'parent'
+        end
+      end
+      
       class AdminQuotaPolicy
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -628,9 +900,45 @@ module Google
         end
       end
       
+      class Analysis
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :analysis, as: 'analysis', class: Google::Apis::ServiceusageV1::AnalysisResult, decorator: Google::Apis::ServiceusageV1::AnalysisResult::Representation
+      
+          property :analysis_type, as: 'analysisType'
+          property :display_name, as: 'displayName'
+          property :service, as: 'service'
+        end
+      end
+      
+      class AnalysisResult
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :blockers, as: 'blockers', class: Google::Apis::ServiceusageV1::Impact, decorator: Google::Apis::ServiceusageV1::Impact::Representation
+      
+          collection :warnings, as: 'warnings', class: Google::Apis::ServiceusageV1::Impact, decorator: Google::Apis::ServiceusageV1::Impact::Representation
+      
+        end
+      end
+      
+      class AnalyzeConsumerPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class AnalyzeConsumerPolicyResponse
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :analysis, as: 'analysis', class: Google::Apis::ServiceusageV1::Analysis, decorator: Google::Apis::ServiceusageV1::Analysis::Representation
+      
+        end
+      end
+      
       class Api
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :edition, as: 'edition'
           collection :methods_prop, as: 'methods', class: Google::Apis::ServiceusageV1::MethodProp, decorator: Google::Apis::ServiceusageV1::MethodProp::Representation
       
           collection :mixins, as: 'mixins', class: Google::Apis::ServiceusageV1::Mixin, decorator: Google::Apis::ServiceusageV1::Mixin::Representation
@@ -645,6 +953,14 @@ module Google
         end
       end
       
+      class Aspect
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :kind, as: 'kind'
+          hash :spec, as: 'spec'
+        end
+      end
+      
       class AuthProvider
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -703,8 +1019,11 @@ module Google
           property :deadline, as: 'deadline'
           property :disable_auth, as: 'disableAuth'
           property :jwt_audience, as: 'jwtAudience'
+          property :load_balancing_policy, as: 'loadBalancingPolicy'
           property :min_deadline, as: 'minDeadline'
           property :operation_deadline, as: 'operationDeadline'
+          hash :overrides_by_request_protocol, as: 'overridesByRequestProtocol', class: Google::Apis::ServiceusageV1::BackendRule, decorator: Google::Apis::ServiceusageV1::BackendRule::Representation
+      
           property :path_translation, as: 'pathTranslation'
           property :protocol, as: 'protocol'
           property :selector, as: 'selector'
@@ -752,6 +1071,39 @@ module Google
         end
       end
       
+      class BatchingConfigProto
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :batch_descriptor, as: 'batchDescriptor', class: Google::Apis::ServiceusageV1::BatchingDescriptorProto, decorator: Google::Apis::ServiceusageV1::BatchingDescriptorProto::Representation
+      
+          property :thresholds, as: 'thresholds', class: Google::Apis::ServiceusageV1::BatchingSettingsProto, decorator: Google::Apis::ServiceusageV1::BatchingSettingsProto::Representation
+      
+        end
+      end
+      
+      class BatchingDescriptorProto
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :batched_field, as: 'batchedField'
+          collection :discriminator_fields, as: 'discriminatorFields'
+          property :subresponse_field, as: 'subresponseField'
+        end
+      end
+      
+      class BatchingSettingsProto
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :delay_threshold, as: 'delayThreshold'
+          property :element_count_limit, as: 'elementCountLimit'
+          property :element_count_threshold, as: 'elementCountThreshold'
+          property :flow_control_byte_limit, as: 'flowControlByteLimit'
+          property :flow_control_element_limit, as: 'flowControlElementLimit'
+          property :flow_control_limit_exceeded_behavior, as: 'flowControlLimitExceededBehavior'
+          property :request_byte_limit, as: 'requestByteLimit'
+          property :request_byte_threshold, :numeric_string => true, as: 'requestByteThreshold'
+        end
+      end
+      
       class Billing
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -804,6 +1156,44 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           collection :destinations, as: 'destinations'
           property :reference_docs_uri, as: 'referenceDocsUri'
+          property :selective_gapic_generation, as: 'selectiveGapicGeneration', class: Google::Apis::ServiceusageV1::SelectiveGapicGeneration, decorator: Google::Apis::ServiceusageV1::SelectiveGapicGeneration::Representation
+      
+        end
+      end
+      
+      class ConsumerPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          hash :annotations, as: 'annotations'
+          collection :enable_rules, as: 'enableRules', class: Google::Apis::ServiceusageV1::EnableRule, decorator: Google::Apis::ServiceusageV1::EnableRule::Representation
+      
+          property :etag, as: 'etag'
+          property :name, as: 'name'
+          property :update_time, as: 'updateTime'
+        end
+      end
+      
+      class ContentSecurity
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :content_security_providers, as: 'contentSecurityProviders', class: Google::Apis::ServiceusageV1::ContentSecurityProvider, decorator: Google::Apis::ServiceusageV1::ContentSecurityProvider::Representation
+      
+        end
+      end
+      
+      class ContentSecurityPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :mcp_content_security, as: 'mcpContentSecurity', class: Google::Apis::ServiceusageV1::ContentSecurity, decorator: Google::Apis::ServiceusageV1::ContentSecurity::Representation
+      
+          property :name, as: 'name'
+        end
+      end
+      
+      class ContentSecurityProvider
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :name, as: 'name'
         end
       end
       
@@ -830,6 +1220,8 @@ module Google
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
           property :environment, as: 'environment'
+          collection :method_policies, as: 'methodPolicies', class: Google::Apis::ServiceusageV1::MethodPolicy, decorator: Google::Apis::ServiceusageV1::MethodPolicy::Representation
+      
         end
       end
       
@@ -897,12 +1289,15 @@ module Google
       class Documentation
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :additional_iam_info, as: 'additionalIamInfo'
           property :documentation_root_url, as: 'documentationRootUrl'
           property :overview, as: 'overview'
           collection :pages, as: 'pages', class: Google::Apis::ServiceusageV1::Page, decorator: Google::Apis::ServiceusageV1::Page::Representation
       
           collection :rules, as: 'rules', class: Google::Apis::ServiceusageV1::DocumentationRule, decorator: Google::Apis::ServiceusageV1::DocumentationRule::Representation
       
+          collection :section_overrides, as: 'sectionOverrides', class: Google::Apis::ServiceusageV1::Page, decorator: Google::Apis::ServiceusageV1::Page::Representation
+      
           property :service_root_url, as: 'serviceRootUrl'
           property :summary, as: 'summary'
         end
@@ -913,6 +1308,7 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           property :deprecation_description, as: 'deprecationDescription'
           property :description, as: 'description'
+          property :disable_replacement_words, as: 'disableReplacementWords'
           property :selector, as: 'selector'
         end
       end
@@ -922,6 +1318,11 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           property :common, as: 'common', class: Google::Apis::ServiceusageV1::CommonLanguageSettings, decorator: Google::Apis::ServiceusageV1::CommonLanguageSettings::Representation
       
+          collection :forced_namespace_aliases, as: 'forcedNamespaceAliases'
+          collection :handwritten_signatures, as: 'handwrittenSignatures'
+          collection :ignored_resources, as: 'ignoredResources'
+          hash :renamed_resources, as: 'renamedResources'
+          hash :renamed_services, as: 'renamedServices'
         end
       end
       
@@ -939,6 +1340,16 @@ module Google
         end
       end
       
+      class EnableRule
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :enable_type, as: 'enableType'
+          collection :groups, as: 'groups'
+          collection :services, as: 'services'
+          collection :values, as: 'values'
+        end
+      end
+      
       class EnableServiceRequest
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -966,6 +1377,7 @@ module Google
       class Enum
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :edition, as: 'edition'
           collection :enumvalue, as: 'enumvalue', class: Google::Apis::ServiceusageV1::EnumValue, decorator: Google::Apis::ServiceusageV1::EnumValue::Representation
       
           property :name, as: 'name'
@@ -987,6 +1399,15 @@ module Google
         end
       end
       
+      class ExperimentalFeatures
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :protobuf_pythonic_types_enabled, as: 'protobufPythonicTypesEnabled'
+          property :rest_async_io_enabled, as: 'restAsyncIoEnabled'
+          property :unversioned_package_disabled, as: 'unversionedPackageDisabled'
+        end
+      end
+      
       class Field
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1004,6 +1425,15 @@ module Google
         end
       end
       
+      class FieldPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :resource_permission, as: 'resourcePermission'
+          property :resource_type, as: 'resourceType'
+          property :selector, as: 'selector'
+        end
+      end
+      
       class GetServiceIdentityMetadata
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1024,6 +1454,7 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           property :common, as: 'common', class: Google::Apis::ServiceusageV1::CommonLanguageSettings, decorator: Google::Apis::ServiceusageV1::CommonLanguageSettings::Representation
       
+          hash :renamed_services, as: 'renamedServices'
         end
       end
       
@@ -1032,6 +1463,8 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           collection :apis, as: 'apis', class: Google::Apis::ServiceusageV1::Api, decorator: Google::Apis::ServiceusageV1::Api::Representation
       
+          collection :aspects, as: 'aspects', class: Google::Apis::ServiceusageV1::Aspect, decorator: Google::Apis::ServiceusageV1::Aspect::Representation
+      
           property :authentication, as: 'authentication', class: Google::Apis::ServiceusageV1::Authentication, decorator: Google::Apis::ServiceusageV1::Authentication::Representation
       
           property :backend, as: 'backend', class: Google::Apis::ServiceusageV1::Backend, decorator: Google::Apis::ServiceusageV1::Backend::Representation
@@ -1143,6 +1576,134 @@ module Google
         end
       end
       
+      class GoogleApiServiceusageV2alphaConsumerPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          hash :annotations, as: 'annotations'
+          property :create_time, as: 'createTime'
+          collection :enable_rules, as: 'enableRules', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaEnableRule, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaEnableRule::Representation
+      
+          property :etag, as: 'etag'
+          property :name, as: 'name'
+          property :update_time, as: 'updateTime'
+        end
+      end
+      
+      class GoogleApiServiceusageV2alphaEnableRule
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :services, as: 'services'
+        end
+      end
+      
+      class GoogleApiServiceusageV2alphaUpdateConsumerPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaAnalysis
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :analysis_result, as: 'analysisResult', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysisResult, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysisResult::Representation
+      
+          property :analysis_type, as: 'analysisType'
+          property :display_name, as: 'displayName'
+          property :service, as: 'service'
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaAnalysisResult
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :blockers, as: 'blockers', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaImpact, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaImpact::Representation
+      
+          collection :warnings, as: 'warnings', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaImpact, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaImpact::Representation
+      
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaAnalyzeConsumerPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :analysis, as: 'analysis', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysis, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysis::Representation
+      
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaConsumerPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :create_time, as: 'createTime'
+          collection :enable_rules, as: 'enableRules', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaEnableRule, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaEnableRule::Representation
+      
+          property :etag, as: 'etag'
+          property :name, as: 'name'
+          property :update_time, as: 'updateTime'
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaEnableRule
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :services, as: 'services'
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaImpact
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :detail, as: 'detail'
+          property :impact_type, as: 'impactType'
+          property :missing_dependency, as: 'missingDependency'
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaMcpEnableRule
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :mcp_services, as: 'mcpServices', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaMcpService, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaMcpService::Representation
+      
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaMcpPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :create_time, as: 'createTime'
+          property :etag, as: 'etag'
+          collection :mcp_enable_rules, as: 'mcpEnableRules', class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaMcpEnableRule, decorator: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaMcpEnableRule::Representation
+      
+          property :name, as: 'name'
+          property :update_time, as: 'updateTime'
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaMcpService
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :service, as: 'service'
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaUpdateConsumerPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class GoogleApiServiceusageV2betaUpdateMcpPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
       class Http
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1170,6 +1731,15 @@ module Google
         end
       end
       
+      class Impact
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :detail, as: 'detail'
+          property :impact_type, as: 'impactType'
+          property :parent, as: 'parent'
+        end
+      end
+      
       class ImportAdminOverridesMetadata
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1247,6 +1817,7 @@ module Google
           property :next_page_token, as: 'nextPageToken'
           collection :operations, as: 'operations', class: Google::Apis::ServiceusageV1::Operation, decorator: Google::Apis::ServiceusageV1::Operation::Representation
       
+          collection :unreachable, as: 'unreachable'
         end
       end
       
@@ -1298,9 +1869,37 @@ module Google
         end
       end
       
+      class McpEnableRule
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :mcp_services, as: 'mcpServices', class: Google::Apis::ServiceusageV1::McpService, decorator: Google::Apis::ServiceusageV1::McpService::Representation
+      
+        end
+      end
+      
+      class McpPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :create_time, as: 'createTime'
+          property :etag, as: 'etag'
+          collection :mcp_enable_rules, as: 'mcpEnableRules', class: Google::Apis::ServiceusageV1::McpEnableRule, decorator: Google::Apis::ServiceusageV1::McpEnableRule::Representation
+      
+          property :name, as: 'name'
+          property :update_time, as: 'updateTime'
+        end
+      end
+      
+      class McpService
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :service, as: 'service'
+        end
+      end
+      
       class MethodProp
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :edition, as: 'edition'
           property :name, as: 'name'
           collection :options, as: 'options', class: Google::Apis::ServiceusageV1::Option, decorator: Google::Apis::ServiceusageV1::Option::Representation
       
@@ -1312,9 +1911,21 @@ module Google
         end
       end
       
+      class MethodPolicy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :request_policies, as: 'requestPolicies', class: Google::Apis::ServiceusageV1::FieldPolicy, decorator: Google::Apis::ServiceusageV1::FieldPolicy::Representation
+      
+          property :selector, as: 'selector'
+        end
+      end
+      
       class MethodSettings
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          collection :auto_populated_fields, as: 'autoPopulatedFields'
+          property :batching, as: 'batching', class: Google::Apis::ServiceusageV1::BatchingConfigProto, decorator: Google::Apis::ServiceusageV1::BatchingConfigProto::Representation
+      
           property :long_running, as: 'longRunning', class: Google::Apis::ServiceusageV1::LongRunning, decorator: Google::Apis::ServiceusageV1::LongRunning::Representation
       
           property :selector, as: 'selector'
@@ -1346,6 +1957,7 @@ module Google
           property :ingest_delay, as: 'ingestDelay'
           property :launch_stage, as: 'launchStage'
           property :sample_period, as: 'samplePeriod'
+          collection :time_series_resource_hierarchy_level, as: 'timeSeriesResourceHierarchyLevel'
         end
       end
       
@@ -1453,6 +2065,7 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           property :common, as: 'common', class: Google::Apis::ServiceusageV1::CommonLanguageSettings, decorator: Google::Apis::ServiceusageV1::CommonLanguageSettings::Representation
       
+          property :library_package, as: 'libraryPackage'
         end
       end
       
@@ -1470,6 +2083,8 @@ module Google
       
           property :new_issue_uri, as: 'newIssueUri'
           property :organization, as: 'organization'
+          property :proto_reference_documentation_uri, as: 'protoReferenceDocumentationUri'
+          property :rest_reference_documentation_uri, as: 'restReferenceDocumentationUri'
         end
       end
       
@@ -1478,6 +2093,8 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           property :common, as: 'common', class: Google::Apis::ServiceusageV1::CommonLanguageSettings, decorator: Google::Apis::ServiceusageV1::CommonLanguageSettings::Representation
       
+          property :experimental_features, as: 'experimentalFeatures', class: Google::Apis::ServiceusageV1::ExperimentalFeatures, decorator: Google::Apis::ServiceusageV1::ExperimentalFeatures::Representation
+      
         end
       end
       
@@ -1519,6 +2136,20 @@ module Google
         end
       end
       
+      class RemoveEnableRulesMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class RemoveEnableRulesResponse
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :parent, as: 'parent'
+          collection :removed_values, as: 'removedValues'
+        end
+      end
+      
       class RubySettings
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1527,6 +2158,14 @@ module Google
         end
       end
       
+      class SelectiveGapicGeneration
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :generate_omitted_as_internal, as: 'generateOmittedAsInternal'
+          collection :methods_prop, as: 'methods'
+        end
+      end
+      
       class ServiceIdentity
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1587,6 +2226,7 @@ module Google
       class Type
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :edition, as: 'edition'
           collection :fields, as: 'fields', class: Google::Apis::ServiceusageV1::Field, decorator: Google::Apis::ServiceusageV1::Field::Representation
       
           property :name, as: 'name'
@@ -1605,6 +2245,24 @@ module Google
         end
       end
       
+      class UpdateConsumerPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class UpdateContentSecurityPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
+      class UpdateMcpPolicyMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+        end
+      end
+      
       class Usage
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
